using Log;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net;
using System.Text;
using System.Threading.Tasks;

namespace Help
{
    public class HttpHelper
    {

        #region GET
        /// <summary>
        /// GET
        /// </summary>
        /// <returns></returns>
        public static string Get(string url)
        {
            string result = "";
            try
            {
                HttpWebRequest req = (HttpWebRequest)WebRequest.Create(url);
                req.Method = "GET";
                req.Accept = "*/*";
                req.CookieContainer = new CookieContainer();

                HttpWebResponse rsp = (HttpWebResponse)req.GetResponse();
                Stream stream = rsp.GetResponseStream();
                //获取响应内容
                using (StreamReader reader = new StreamReader(stream, Encoding.UTF8))
                {
                    result = reader.ReadToEnd();
                }
                //LogSys.Info("result: " + result);
            }
            catch (Exception e)
            {
                LogSys.Error("error: " + e.Message + url);
            }
            return result;
        }
        #endregion

        #region POST

        /// <summary>
        /// POST-指定地址
        /// </summary>
        /// <param name="url">地址</param>
        /// <returns></returns>
        public static string Post(string url)
        {
            string result = "";
            HttpWebRequest req = (HttpWebRequest)WebRequest.Create(url);
            req.Method = "POST";
            req.ContentLength = 0;
            HttpWebResponse rsp = (HttpWebResponse)req.GetResponse();
            Stream stream = rsp.GetResponseStream();
            //获取响应内容
            using (StreamReader reader = new StreamReader(stream, Encoding.UTF8))
            {
                result = reader.ReadToEnd();
            }
            return result;
        }

        /// <summary>
        /// POST-指定地址+键值
        /// </summary>
        /// <param name="url">地址</param>
        /// <param name="dic">键值字典</param>
        /// <returns></returns>
        public static string Post(string url, Dictionary<string, string> dic)
        {
            string result = "";
            HttpWebRequest req = (HttpWebRequest)WebRequest.Create(url);
            req.Method = "POST";
            req.ContentType = "application/x-www-form-urlencoded";

            #region 添加post参数

            StringBuilder builder = new StringBuilder();
            int i = 0;
            foreach (var item in dic)
            {
                if (i > 0)
                    builder.Append("&");
                builder.AppendFormat("{0}={1}", item.Key, item.Value);
                i++;
            }
            Log.LogSys.Info("url:" + url);
            Log.LogSys.Info("Pre Post:" + builder.ToString());

            byte[] data = Encoding.UTF8.GetBytes(builder.ToString());
            req.ContentLength = data.Length;
            using (Stream reqStream = req.GetRequestStream())
            {
                reqStream.Write(data, 0, data.Length);
                reqStream.Close();
            }
            #endregion
            HttpWebResponse rsp = (HttpWebResponse)req.GetResponse();
            Stream stream = rsp.GetResponseStream();
            //获取响应内容
            using (StreamReader reader = new StreamReader(stream, Encoding.UTF8))
            {
                result = reader.ReadToEnd();
            }
            return result;
        }

        /// <summary>
        /// POST-指定地址+内容
        /// </summary>
        /// <param name="url">地址</param>
        /// <param name="content">内容</param>
        /// <returns></returns>
        public static string Post(string url, string content)
        {
            LogSys.Debug("url:" + url);
            string result = "";
            //Task.Run(() =>
            //{
            try
            {
                HttpWebRequest req = (HttpWebRequest)WebRequest.Create(url);
                req.Method = "POST";
                req.ContentType = "application/json;charset=utf-8";
                //req.ContentType = "application/x-www-form-urlencoded;charset=utf-8";

                #region 添加post参数

                byte[] data = Encoding.UTF8.GetBytes(content);
                req.ContentLength = data.Length;
                using (Stream reqStream = req.GetRequestStream())
                {
                    reqStream.Write(data, 0, data.Length);
                    reqStream.Close();
                }

                #endregion
                LogSys.Debug("1---------------------------");
                HttpWebResponse rsp = (HttpWebResponse)req.GetResponse();
                Stream stream = rsp.GetResponseStream();
                //获取响应内容
                using (StreamReader reader = new StreamReader(stream, Encoding.UTF8))
                {
                    LogSys.Debug("2---------------------------");

                    result = reader.ReadToEnd();

                    Log.LogSys.Debug("3----------------------------" + result);
                }
            }
            catch (Exception e)
            {
                LogSys.Debug("e" + e);
            }
            return result;
            //});
            // return result;
        }

        #endregion

    }
}
